# -*- coding: utf-8 -*-
# Generated by Django 1.10.3 on 2017-06-24 14:39
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Log',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('action', models.CharField(choices=[('', ''), ('created', 'created'), ('updated', 'updated'), ('deleted', 'deleted')], default='', max_length=10)),
                ('message', models.CharField(max_length=255)),
                ('func_name', models.CharField(max_length=255)),
                ('level', models.CharField(choices=[('', ''), ('CRITICAL', 'CRITICAL'), ('ERROR', 'ERROR'), ('WARNING', 'WARNING'), ('INFO', 'INFO'), ('DEBUG', 'DEBUG'), ('NOTSET', 'NOTSET')], default='NOTSET', max_length=10)),
                ('http_general', models.TextField(blank=True)),
                ('http_request_get', models.TextField(blank=True)),
                ('http_request_post', models.TextField(blank=True)),
                ('http_referrer', models.CharField(blank=True, max_length=255)),
                ('user_id', models.IntegerField(db_index=True, null=True)),
                ('username', models.CharField(blank=True, db_index=True, max_length=255)),
                ('object_name', models.CharField(blank=True, db_index=True, max_length=255)),
                ('object_id', models.IntegerField(db_index=True, null=True)),
                ('object_data', models.TextField(blank=True)),
                ('extra', models.TextField(blank=True)),
                ('dc', models.DateTimeField(auto_now_add=True)),
            ],
        ),
    ]
